# PolicyEngine Reweight

The PolicyEngine reweight library is a library intended to reweight survey data based on known ground truth statistics, to adjust for sampling biases. This library is designed for use with the [PolicyEngine](https://policyengine.org) software packages.

Currently, this library is still very much a work in progress, and lacks e.g. systematic functions for the reweighting code, and the ability to reweight any survey data not already converted to PyTorch tensors.
